@@ -1,5 +1,7 @@
 use parent 'Action';
 
+### An Action on which you hit with a functor such as in Action.pm
+
 sub new {
 	my $class = shift;
 
@@ -9,8 +11,9 @@ sub new {
 };
 
 sub doHit {
-	($self, $hittedEntity) = @_;
+	$self = shift;
 
+	$self->{hitmethod}->do(@_);
 };	
 
 1;
