@@ -1,5 +1,7 @@
 use parent 'Action';
 
+### An Action on which you take a hit based on functors in Action.pm
+
 sub new {
 	my $class = shift;
 
@@ -9,8 +11,9 @@ sub new {
 };
 
 sub takeHit {
-	($self, $hittingEntity) = @_;
+	$self = shift;
 
+	$self->{tohitmethod}->do(@_);
 };	
 
 1;
